/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.core.chunk.larkc;

import java.util.Collection;

import org.jactr.core.chunk.IChunk;
import org.jactr.core.chunk.ISymbolicChunk;
import org.jactr.core.chunktype.IChunkType;
import org.jactr.core.slot.IMutableSlot;

import eu.larkc.core.data.InformationSet;
import eu.larkc.core.query.Query;
import eu.larkc.jactr.core.chunk.rdf.BasicSymbolicChunkRdf;
import eu.larkc.jactr.core.chunk.rdf.DefaultChunkRdf;

/**
 * The symbolic half of an RDF chunk.
 * 
 * @author Martijn Brakenhoff
 * @created April 29, 2010
 */
public class BasicSymbolicChunkLarKC extends BasicSymbolicChunkRdf implements
		ISymbolicChunkLarKC {
	
//	private static final transient Log 	LOGGER = LogFactory.getLog(BasicSymbolicChunkLarKC.class);
	
	private Object _larKCData;

	public BasicSymbolicChunkLarKC(DefaultChunkRdf parentChunk, IChunkType ct) {
		super(parentChunk, ct);
	}

	/**
	 * create a symbolicchunk that has the same values as reference this is used
	 * when making copies of the chunk
	 */
	protected BasicSymbolicChunkLarKC(IChunk realParent, ISymbolicChunk reference) {
		super(realParent, reference);
		
		if (reference instanceof ISymbolicChunkLarKC) {
			Object data = ((ISymbolicChunkLarKC) reference).getLarKCData();
			if (data instanceof InformationSet) {
				setLarKCData( (InformationSet) data );
			} else if (data instanceof Query) {
				setLarKCData( (Query) data );
			} else if (data instanceof Collection<?>) {
				setLarKCDataCollection( (Collection<?>) data );
			}
		}
	}
	
	protected void setData(Object data) {
		_larKCData = data;
		((IMutableSlot) getSlot(RDF_SLOT_NAME)).setValue(data);
	}
	
	public Object getLarKCData() {
		return _larKCData;
	}

	public void setLarKCData(InformationSet data) {
		setData(data);
	}

	public void setLarKCData(Query data) {
		setData(data);
	}

	public void setLarKCDataCollection(Collection<?> data)
			throws IllegalArgumentException {
		setData(data);
	}

}
