/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.core.chunk.larkc;

import java.util.Collection;

import eu.larkc.core.data.InformationSet;
import eu.larkc.core.query.Query;
import eu.larkc.jactr.core.chunk.rdf.ISymbolicChunkRdf;

/**
 * Symbolic chunks that implement this interface contain LarKC-Result data. 
 * 
 * @author Martijn Brakenhoff
 * @created March 10, 2010
 */
public interface ISymbolicChunkLarKC extends ISymbolicChunkRdf {
	
	public static final String LARKC_DATA_CHUNKTYPE_NAME = "LarKCData";
	
	/**
	 * Sets the LarKC Data to the given InformationSet.
	 * 
	 * @param data the InformationSet that should be stored in this chunk.
	 */
	public void setLarKCData (InformationSet data);
	
	/**
	 * Sets the LarKC Data to the given Query.
	 * 
	 * @param data the Query that should be stored in this chunk.
	 */
	public void setLarKCData (Query data);
	
	/**
	 * Sets the LarKC Data to be the given Collection. Accepts only 
	 * Collection<InformationSet> and Collection<Query> objects.
	 * 
	 * @param data A Collection that should be used as the LarKC data. 
	 * @throws IllegalArgumentException if the data was not a 
	 * Collection<InformationSet> or a Collection<Query>.
	 */
	public void setLarKCDataCollection (Collection<?> data) throws IllegalArgumentException;
	
	/**
	 * Retrieve the LarKC Data stored in this Chunk.  
	 * 
	 * @return the data stored in this chunk. 
	 */
	public Object getLarKCData ();

}
