/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.modules.larkc.plugin;

/**
 * A jACT-R module that wraps a LarKC Plug-in must implement 
 * this interface. Modules that implement this interface should 
 * be initialized with the parameters: PluginBuffer, PluginURI, 
 * PluginInput and PluginOutput
 * 
 * @author Martijn Brakenhoff
 * @created April 2, 2010
 */
public interface ILarKCPluginModule {
	
	public static final String  PLUGIN_URI 		= "PluginURI",
								BUFFER_NAME 	= "BufferName";

	/**
	 * Returns the PluginURI parameter that was supplied to 
	 * this module.
	 * 
	 * @return the Plug-in URI specified in the model.
	 */
	public String getPluginURI ();
	
	/**
	 * Sets the URI that specifies the LarKC Plug-in that 
	 * will be wrapped by this module.
	 * 
	 * @param uri the Plug-in URI
	 */
	public void setPluginURI (String uri); 

	/**
	 * Sets the buffer name that will be used by this module. 
	 * This is a necessity, because multiple instances of this
	 * module are necessary to create a Workflow.
	 * 
	 * @param name the buffer name.
	 */
	public void setBufferName (String name);

	/**
	 * Checks if the plug-in manager thread is still running or 
	 * has terminated.
	 * 
	 * @return True if the plug-in manager is still alive, 
	 * otherwise false. 
	 */
	public boolean isAlive();
}
