/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.modules.larkc.plugin;

import java.util.Map;
import java.util.TreeMap;

import org.jactr.core.module.retrieval.IRetrievalModule;
import org.jactr.core.module.retrieval.four.IRetrievalModule4;
import org.jactr.io.participant.impl.BasicASTParticipant;

import eu.larkc.jactr.modules.larkc.plugin.LarKCPluginModule;
import eu.larkc.jactr.modules.larkc.plugin.LarKCPluginParticipant;

/**
 * The IASTParticipant takes the location of a model descriptor (with no modules) 
 * and installs the contents into the model passed to it.<br>
 * <br>
 * All you need to do is create the model file and set its location to DEFAULT_LOCATION<br>
 * <br>
 * If your module has parameters (implements IParameterized), you can set the
 * default values via createParameterMap()
 */
public class LarKCPluginParticipant extends BasicASTParticipant {

  /**
   * default location of the model content to import or trim
   */
  static private final String DEFAULT_LOCATION = "eu/larkc/jactr/modules/larkc/plugin/larkcPlugin.jactr";
  
  /**
   * A zero arg constructor. Resource loaded here for use at runtime, 
   * also add resource to plugin.xml for build-time use.
   */
  public LarKCPluginParticipant() {
    super(LarKCPluginParticipant.class.getClassLoader().getResource(DEFAULT_LOCATION));
    setInstallableClass(LarKCPluginModule.class);

    Map<String, String> parameters = new TreeMap<String, String>();
    parameters.put(IRetrievalModule.RETRIEVAL_THRESHOLD, "0");
    parameters.put(IRetrievalModule4.LATENCY_FACTOR, "20");
    parameters.put(LarKCPluginModule.BUFFER_NAME, "larkc");
    setParameterMap(parameters);
  }
}

